@@ -270,10 +270,10 @@ active_connections_button_clicked  (GtkToolButton *button,
       gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 
       label = vinagre_connection_get_best_name (conn);
-      if ((l->data == tab) && (GTK_IS_LABEL (GTK_BIN (item)->child)))
+      if ((l->data == tab) && (GTK_IS_LABEL (gtk_bin_get_child (GTK_BIN (item)))))
 	{
 	  str = g_strdup_printf ("<b>%s</b>", label);
-	  gtk_label_set_use_markup (GTK_LABEL (GTK_BIN (item)->child), TRUE);
+	  gtk_label_set_use_markup (GTK_LABEL (gtk_bin_get_child GTK_BIN (item)), TRUE);
 	  g_free (label);
 	  label = str;
 	}
@@ -316,7 +316,7 @@ setup_layout (VinagreTab *tab)
 
   tab->priv->toolbar = gtk_toolbar_new ();
   gtk_toolbar_set_show_arrow (GTK_TOOLBAR (tab->priv->toolbar), FALSE);
-  GTK_WIDGET_SET_FLAGS (tab->priv->toolbar, GTK_NO_SHOW_ALL);
+  gtk_widget_set_no_show_all (tab->priv->toolbar, TRUE);
 
   gtk_toolbar_set_style (GTK_TOOLBAR (tab->priv->toolbar), GTK_TOOLBAR_BOTH_HORIZ);
 
@@ -354,6 +354,8 @@ setup_layout (VinagreTab *tab)
   ViewOvBox_SetUnder (VIEW_OV_BOX (tab->priv->layout), tab->priv->scroll);
   ViewAutoDrawer_SetOffset (VIEW_AUTODRAWER (tab->priv->layout), -1);
   ViewAutoDrawer_SetFill (VIEW_AUTODRAWER (tab->priv->layout), FALSE);
+  ViewAutoDrawer_SetOverlapPixels (VIEW_AUTODRAWER (tab->priv->layout), 1);
+  ViewAutoDrawer_SetNoOverlapPixels (VIEW_AUTODRAWER (tab->priv->layout), 0);
 
   gtk_box_pack_end (GTK_BOX(tab), tab->priv->layout, TRUE, TRUE, 0);
   gtk_widget_show_all (GTK_WIDGET (tab));
@@ -829,6 +831,7 @@ vinagre_tab_take_screenshot (VinagreTab *tab)
 
   name = vinagre_connection_get_best_name (tab->priv->conn);
   suggested_filename = g_string_new (NULL);
+  /* Translators: This is the suggested filename (in save dialog) when taking a screenshot of the connection. %s will be replaced by the friendly name of the connection, for instance: Screenshot of wendell@wendell-laptop, or Screenshot of 200.100.100.123 */
   g_string_printf (suggested_filename, _("Screenshot of %s"), name);
   g_string_append (suggested_filename, ".png");
   g_free (name);
